==> org.eclipse.rap.tools.templates.source_3.6.0.20180912-0855.jar: org/eclipse/rap/tools/templates/internal/XmlNames.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2013 EclipseSource
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Innoopract Informationssysteme GmbH - initial API and implementation
 *    EclipseSource - ongoing development
 ******************************************************************************/
package org.eclipse.rap.tools.templates.internal;

/**
 * Commonly used XML elements, attributes and extension point ids.
 */
public final class XmlNames {

  public static final String ATT_ALLOWMULTIPLE = "allowMultiple"; //$NON-NLS-1$
  public static final String ATT_CLASS = "class"; //$NON-NLS-1$
  public static final String ATT_DESCRIPTION = "description"; //$NON-NLS-1$
  public static final String ATT_CATID = "categoryId"; //$NON-NLS-1$
  public static final String ATT_ICON = "icon"; //$NON-NLS-1$
  public static final String ATT_ID = "id"; //$NON-NLS-1$
  public static final String ATT_NAME = "name"; //$NON-NLS-1$
  public static final String ATT_VALUE = "value"; //$NON-NLS-1$
  public static final String ATT_SERVLET_PATH = "path"; //$NON-NLS-1$
  public static final String ATT_DEFAULT_ENTRYPOINT = "defaultEntrypointId"; //$NON-NLS-1$
  public static final String ATT_THEME_ID = "themeId"; //$NON-NLS-1$
  public static final String ATT_TITLE = "title"; //$NON-NLS-1$
  public static final String ATT_DEFAULT_LAYOUT = "defaultLayoutId"; //$NON-NLS-1$
  public static final String ATT_CARDINALITY = "cardinality"; //$NON-NLS-1$
  public static final String ATT_THREAD = "thread"; //$NON-NLS-1$
  public static final String ATT_VISIBLE = "visible"; //$NON-NLS-1$
  public static final String ATT_APPLICATION_ID = "applicationId"; //$NON-NLS-1$
  public static final String ATT_BRANDING_ID = "brandingId"; //$NON-NLS-1$

  public static final String ELEM_ENTRYPOINT = "entrypoint"; //$NON-NLS-1$
  public static final String ELEM_APPLICATION = "application"; //$NON-NLS-1$
  public static final String ELEM_RUN = "run"; //$NON-NLS-1$
  public static final String ELEM_PARAMETER = "parameter"; //$NON-NLS-1$
  public static final String ELEM_CATEGORY = "category"; //$NON-NLS-1$
  public static final String ELEM_COMMAND = "command"; //$NON-NLS-1$
  public static final String ELEM_PERSPECTIVE = "perspective"; //$NON-NLS-1$
  public static final String ELEM_VIEW = "view"; //$NON-NLS-1$
  public static final String ELEM_BRANDING = "branding"; //$NON-NLS-1$
  public static final String ELEM_PRESENTATIONFACTORY = "presentationFactory"; //$NON-NLS-1$
  public static final String ELEM_DEFAULTSTACKPRESENTATION = "defaultStackPresentation"; //$NON-NLS-1$

  public static final String XID_COMMANDS = "org.eclipse.ui.commands"; //$NON-NLS-1$
  public static final String XID_APPLICATION = "org.eclipse.core.runtime.applications"; //$NON-NLS-1$
  public static final String XID_PERSPECTIVES = "org.eclipse.ui.perspectives"; //$NON-NLS-1$
  public static final String XID_VIEWS = "org.eclipse.ui.views"; //$NON-NLS-1$
  public static final String XID_BRANDING = "org.eclipse.rap.ui.branding"; //$NON-NLS-1$
  public static final String XID_ENTRYPOINT = "org.eclipse.rap.ui.entrypoint"; //$NON-NLS-1$

}

==> org.eclipse.rap.tools.templates.source_3.17.0.20210609-1200.jar: org/eclipse/rap/tools/templates/internal/XmlNames.java <==
/*******************************************************************************
 * Copyright (c) 2007, 2013 EclipseSource
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Innoopract Informationssysteme GmbH - initial API and implementation
 *    EclipseSource - ongoing development
 ******************************************************************************/
package org.eclipse.rap.tools.templates.internal;

/**
 * Commonly used XML elements, attributes and extension point ids.
 */
public final class XmlNames {

  public static final String ATT_ALLOWMULTIPLE = "allowMultiple"; //$NON-NLS-1$
  public static final String ATT_CLASS = "class"; //$NON-NLS-1$
  public static final String ATT_DESCRIPTION = "description"; //$NON-NLS-1$
  public static final String ATT_CATID = "categoryId"; //$NON-NLS-1$
  public static final String ATT_ICON = "icon"; //$NON-NLS-1$
  public static final String ATT_ID = "id"; //$NON-NLS-1$
  public static final String ATT_NAME = "name"; //$NON-NLS-1$
  public static final String ATT_VALUE = "value"; //$NON-NLS-1$
  public static final String ATT_SERVLET_PATH = "path"; //$NON-NLS-1$
  public static final String ATT_DEFAULT_ENTRYPOINT = "defaultEntrypointId"; //$NON-NLS-1$
  public static final String ATT_THEME_ID = "themeId"; //$NON-NLS-1$
  public static final String ATT_TITLE = "title"; //$NON-NLS-1$
  public static final String ATT_DEFAULT_LAYOUT = "defaultLayoutId"; //$NON-NLS-1$
  public static final String ATT_CARDINALITY = "cardinality"; //$NON-NLS-1$
  public static final String ATT_THREAD = "thread"; //$NON-NLS-1$
  public static final String ATT_VISIBLE = "visible"; //$NON-NLS-1$
  public static final String ATT_APPLICATION_ID = "applicationId"; //$NON-NLS-1$
  public static final String ATT_BRANDING_ID = "brandingId"; //$NON-NLS-1$
  public static final String ATT_APPLICATION = "application"; //$NON-NLS-1$

  public static final String ELEM_ENTRYPOINT = "entrypoint"; //$NON-NLS-1$
  public static final String ELEM_APPLICATION = "application"; //$NON-NLS-1$
  public static final String ELEM_RUN = "run"; //$NON-NLS-1$
  public static final String ELEM_PARAMETER = "parameter"; //$NON-NLS-1$
  public static final String ELEM_CATEGORY = "category"; //$NON-NLS-1$
  public static final String ELEM_COMMAND = "command"; //$NON-NLS-1$
  public static final String ELEM_PERSPECTIVE = "perspective"; //$NON-NLS-1$
  public static final String ELEM_VIEW = "view"; //$NON-NLS-1$
  public static final String ELEM_BRANDING = "branding"; //$NON-NLS-1$
  public static final String ELEM_PRESENTATIONFACTORY = "presentationFactory"; //$NON-NLS-1$
  public static final String ELEM_DEFAULTSTACKPRESENTATION = "defaultStackPresentation"; //$NON-NLS-1$
  public static final String ELEM_PRODUCT = "product"; //$NON-NLS-1$

  public static final String XID_COMMANDS = "org.eclipse.ui.commands"; //$NON-NLS-1$
  public static final String XID_APPLICATION = "org.eclipse.core.runtime.applications"; //$NON-NLS-1$
  public static final String XID_PERSPECTIVES = "org.eclipse.ui.perspectives"; //$NON-NLS-1$
  public static final String XID_VIEWS = "org.eclipse.ui.views"; //$NON-NLS-1$
  public static final String XID_BRANDING = "org.eclipse.rap.ui.branding"; //$NON-NLS-1$
  public static final String XID_ENTRYPOINT = "org.eclipse.rap.ui.entrypoint"; //$NON-NLS-1$
  public static final String XID_PRODUCT = "org.eclipse.core.runtime.products"; //$NON-NLS-1$

}
